
# Contrib folder

This is the "contribution folder". It contains additional useful functions that do not belong to the core of gate.

See the online doc for more details: https://opengate-python.readthedocs.io/en/latest/user_guide.html in the section "Contributions".
